﻿using Ozeki.VoIP;

namespace CustomDialplan
{
    class MyDialplanProvider : IDialplanProvider
    {
        UserInfoContainer userInfoContainer;
        IExtensionContainer extensionContainer;

        public MyDialplanProvider(UserInfoContainer userInfoContainer, IExtensionContainer extensionContainer)
        {
            this.userInfoContainer = userInfoContainer;
            this.extensionContainer = extensionContainer;
        }

        #region IDialplanProvider Members

        public string Name
        {
            get { return "CustomDialplan"; }
        }

        public IDialplanResult GetDestination(RouteInfo routeInfo)
        {
            var currentDialed = routeInfo.DialInfo.Dialed;

            // if dialed number was busy or not answered, hang up call
            if (routeInfo.State != RoutingState.Calling)
            {
                return null;
            }

            // if "200" dialed, ring the first available extension
            if (currentDialed == "200")
            {
                var userInfos = userInfoContainer.GetUserInfos();
                foreach (var userInfo in userInfos)
                {
                    // skip the caller extension
                    if (userInfo.UserName == routeInfo.SourceExtension.ExtensionID)
                        continue;

                    var extension = extensionContainer.GetExtension(userInfo.UserName);
                    if (extension != null)
                        return new Destination(extension.ExtensionID);
                }

                return null;
            }

            // if the dialed number was 300, send redirection response to the SIP extension
            if (currentDialed == "300")
            {
                return new RedirectDestination("103");
            }

            return new Destination(currentDialed);
        }

        public SessionMode GetSessionMode(IBaseCall caller, IBaseCall callee, SessionMode defaultSessionMode)
        {
            return defaultSessionMode;
        }

        #endregion
    }
}
